package CatalystX::HelpText::Model;
use Moose;
use MooseX::Types::Moose qw/Str Undef/;
use MooseX::Types::Path::Class qw/ Dir /;
use Moose::Autobox;
use Carp qw/ croak confess/;
use namespace::autoclean;

extends 'Catalyst::Model';

has help_files_path => (
    is => 'ro',
    isa => Dir,
    coerce => 1,
    required => 1,
    handles => {
        _get_file => 'file',
    }
);

has help_files_ext => (
    is => 'ro',
    isa => Str|Undef,
    default => 'html',
);

has wrapper_css_class => (
    is => 'ro',
    isa => Str,
    default => 'help_text',
);

has wrapper_tag => (
    is => 'ro',
    isa => Str,
    default => 'span',
);


sub get_help_text_for {
    my ($self, $help_key) = @_;
    confess('No $help_key provided') unless $help_key;

    my $fn = $help_key;
    $fn .= "." . $self->help_files_ext if defined($self->help_files_ext);

    my $file = $self->_get_file($fn);

    if ( -e $file ) {
        return sprintf('<%s class="%s">%s</%s>',
            $self->wrapper_tag,
            $self->wrapper_css_class,
            $file->slurp,
            $self->wrapper_tag
        );
    }

    croak "Cannot find help text '$help_key' in $file";
}

1;

